@@ -3,6 +3,7 @@ from .security import models
 from .security import use_cases
 from .security import auth
 from .security import schema
+from .security import repository
 from .security.commands import command_auth_mongo
 from .security.middlewares import MutationMiddleware
 from .constants.security import Roles
@@ -14,6 +15,7 @@ __all__ = (
     'command_auth_mongo',
     'models',
     'schema',
+    'repository',
     'use_cases',
     'MutationMiddleware',
     'Roles',
