@@ -2,19 +2,19 @@ from flask import request
 from ..use_cases import Login, Logout
 
 
-def login(role):
+def login(role=None):
     """login for API Rest
 
     Args:
-        role (str):
+        role (str|List[str]): Nullable
 
     Returns:
         (dict, int): (data, http_code)
     """
     use_case = Login()
     result = use_case.handle(
-        role=role,
-        request=request.get_json()
+        request=request.get_json(),
+        role=role
     )
 
     response = dict(
@@ -26,7 +26,8 @@ def login(role):
             token_type=result.tokens.token_type,
             refresh_token=result.tokens.refresh_token,
             expires_in=result.tokens.expires_in,
-            change_password=result.change_password
+            change_password=result.change_password,
+            role=result.role
         )
     return response, result.http_code
 
