@@ -48,7 +48,13 @@ def required(role: str = None, require_password_change: bool = None):
                 # header sin "Authorization"
                 return _response_unauthorized()
 
-            auth_type, token = authorization.split(' ')
+            params = authorization.split(' ')
+
+            if len(params) != 2:
+                return _response_unauthorized()
+
+            auth_type, token = params
+
             if auth_type != 'Bearer':
                 # Tipo de "Authorization" no valido
                 return _response_unauthorized()
@@ -71,6 +77,10 @@ def required(role: str = None, require_password_change: bool = None):
                 # Usuario no encontrado
                 return _response_unauthorized()
 
+            if not user.active:
+                # Usuario apagado
+                return _response_unauthorized()
+
             if role and user.role.name not in role:
                 # Role incorrecto
                 return _response_unauthorized()
