@@ -36,15 +36,18 @@ class AuthResponse(Response):
         message (str)
         errors (list)
     """
+
     def __init__(
         self,
         tokens: str = None,
         change_password: bool = None,
+        role: str = None,
         *args,
         **kwargs
     ):
         self.tokens = tokens
         self.change_password = change_password
+        self.role = role
 
         super().__init__(*args, **kwargs)
 
@@ -113,7 +116,8 @@ class Login(BaseAuth):
         return AuthResponse(
             message=responses.OK,
             tokens=self._new_tokens(self._user),
-            change_password=self._user.change_password
+            change_password=self._user.change_password,
+            role=self._user.role.name
         )
 
     def __credential_conditions(self) -> tuple:
