@@ -27,20 +27,20 @@ class TestUserNew(TestCase):
             'new', [
                 '-r', 'a role',
                 '-u', 'an username',
-                '--password', 'a pass',
-                '-f', '123456'
+                '--password', 'a pass'
             ]
         )
 
         self.assertEqual(context.params['role'], 'a role')
         self.assertEqual(context.params['username'], 'an username')
         self.assertEqual(context.params['password'], 'a pass')
-        self.assertEqual(context.params['funder_identifier'], '123456')
 
 
 class TestClearTokens(TestCase):
 
     def test_params(self):
-        context = clear_tokens.make_context('clear-tokens', [])
+        context = clear_tokens.make_context('clear-tokens', ['-f'])
+        self.assertEqual(context.params['forced'], True)
 
-        self.assertEqual(context.params, {})
+        context = clear_tokens.make_context('clear-tokens', [])
+        self.assertEqual(context.params['forced'], False)
